@@ -3,6 +3,7 @@
  * logging.c - logging functions
  *
  * Copyright (C) 1999, 2000, 2002 Ben Collins <bcollins@debian.org>
+ * Copyright (C) 2009 Timur Birsh <taem@linukz.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
@@ -16,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with sxid; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -348,6 +349,7 @@ void init_file_entries (void)
 
 	if (p == NULL) {
 	    fprintf (stderr, "E: could not malloc() in init_file_entries()\n");
+	    fclose (log);
 	    exit (1);
 	}
 	p->next = global_log;
@@ -371,6 +373,7 @@ void init_file_entries (void)
 	p->flags = 0;
 	p->flags |= FE_OLD;
     }
+    fclose (log);
     return;
 }
 
